@@ -12,12 +12,15 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION = 0.96001;
+our $VERSION = 0.96002;
 our $workflow = App::Git::Workflow->new;
 my ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
+our %p2u_extra;
 
 sub run {
+    my ($self) = @_;
+
     %option = (
         exclude    => [],
         max_age    => ( $ENV{GIT_WORKFLOW_MAX_AGE} || $workflow->config('workflow.max') || 120 ),
@@ -42,8 +45,15 @@ sub run {
     my $max      = 0;
     my @branches = $workflow->branches($option{remote} ? 'remote' : $option{all} ? 'both' : undef );
     my @excludes = @{ $option{exclude} };
+    my $action   = 'do_' . ( $ARGV[0] || 'delete' );
     my ($total, $deleted) = (0, 0);
 
+    if (!$self->can($action)) {
+        warn "Unknown action $ARGV[0]!\n";
+        Pod::Usage::pod2usage( %p2u_extra, -verbose => 1 );
+        return 1;
+    }
+
     if ($option{exclude_file}) {
         for my $exclude ($workflow->slurp($option{exclude_file})) {
             chomp $exclude;
@@ -66,33 +76,7 @@ sub run {
         next BRANCH if too_young_to_die($details);
 
         $max = $details->{time} if $max < $details->{time};
-            my $too_old = too_old($details);
-        my $in_master;
-
-        if (!$too_old) {
-            $in_master = in_master($details);
-        }
-
-        if ( $in_master || $too_old ) {
-            warn 'deleting ' . ($in_master ? 'merged' : 'old') . " branch $branch\n";
-            $deleted++;
-
-            my ($remote, $name) = $branch =~ m{/} ? split m{/}, $branch, 2 : (undef, $branch);
-
-            if ( $option{tag} ) {
-                my $tag = $option{tag_prefix} . $name . $option{tag_suffix};
-                $workflow->git->tag(qw/-a -m /, "Converting '$name' to the tag '$tag'", $tag) if !$option{test};
-            }
-
-            if ( !$option{test} ) {
-                if ($remote) {
-                    $workflow->git->push($remote, ":refs/heads/$name");
-                }
-                else {
-                    $workflow->git->branch('-D', "$name");
-                }
-            }
-        }
+        $deleted += __PACKAGE__->$action($branch, $details);
         $total++;
     }
 
@@ -101,6 +85,41 @@ sub run {
     return;
 }
 
+sub do_delete {
+    my ($self, $branch, $details) = @_;
+
+    my $too_old = too_old($details);
+    my $in_master;
+
+    if (!$too_old) {
+        $in_master = in_master($details);
+    }
+
+    if ( $in_master || $too_old ) {
+        warn 'deleting ' . ($in_master ? 'merged' : 'old') . " branch $branch\n";
+
+        my ($remote, $name) = $branch =~ m{/} ? split m{/}, $branch, 2 : (undef, $branch);
+
+        if ( $option{tag} ) {
+            my $tag = $option{tag_prefix} . $name . $option{tag_suffix};
+            $workflow->git->tag(qw/-a -m /, "Converting '$name' to the tag '$tag'", $tag) if !$option{test};
+        }
+
+        if ( !$option{test} ) {
+            if ($remote) {
+                $workflow->git->push($remote, ":refs/heads/$name");
+            }
+            else {
+                $workflow->git->branch('-D', "$name");
+            }
+        }
+
+        return 1;
+    }
+
+    return 0;
+}
+
 sub in_master {
     my ($details) = @_;
 
@@ -135,7 +154,7 @@ git-branch-clean - Clean old branches out of the repository
 
 =head1 VERSION
 
-This documentation refers to git-branch-clean version 0.96001
+This documentation refers to git-branch-clean version 0.96002
 
 =head1 SYNOPSIS
 
@@ -183,6 +202,10 @@ an optional suffix (C<--tag-suffix>) added.
 
 Executes the git workflow command
 
+=head2 C<do_delete ($branch, $details)>
+
+Performs the deleting of old branches.
+
 =head2 C<in_master ($details)>
 
 The branch with C<$details> has been merged to master
