@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.96001;
+our $VERSION  = 0.96002;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -48,7 +48,7 @@ sub run {
 
     while ($once) {
         my ($id, @rest) = git_state();
-        print {*STDERR} '.' if $option{verbose};
+        spin() if $option{verbose};
 
         if ( $last ne $id ) {
             $once++;
@@ -139,6 +139,26 @@ sub changes {
     return $changes;
 }
 
+{
+    my $spinner;
+    sub spin {
+        if (!defined $spinner) {
+            $spinner = 0;
+            eval { require Term::Spinner };
+            return if $@;
+            $spinner = Term::Spinner->new();
+        }
+        elsif (!$spinner) {
+            print {*STDERR} '.';
+            return;
+        }
+
+        return $spinner->advance;
+    }
+}
+
+1;
+
 __DATA__
 
 =head1 NAME
@@ -147,7 +167,7 @@ git-watch - Watch for changes in repository up-stream
 
 =head1 VERSION
 
-This documentation refers to git-watch version 0.96001
+This documentation refers to git-watch version 0.96002
 
 =head1 SYNOPSIS
 
@@ -228,6 +248,10 @@ Executes the git workflow command
 
 =head2 C<changes ()>
 
+=head2 C<spin ()>
+
+Helper providing access to Term::Spinner if installed
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
