@@ -16,7 +16,7 @@ use App::Git::Workflow::Repository qw//;
 use App::Git::Workflow;
 use base qw/App::Git::Workflow/;
 
-our $VERSION = 0.96001;
+our $VERSION = 0.96002;
 
 sub new {
     my $class = shift;
@@ -85,7 +85,13 @@ sub get_pom_versions {
 
             $branch =~ s{^origin/}{}xms;
 
-            my $numerical = my $version = $self->pom_version($xml);
+            my $numerical = my $version = eval { $self->pom_version($xml) };
+
+            # make sure we get a valid version
+            if ( $@ || !defined $numerical ) {
+                next BRANCH;
+            }
+
             # remove snapshots from the end
             $numerical =~ s/-SNAPSHOT$//xms;
             # remove any extranious text from the front
@@ -145,7 +151,7 @@ App::Git::Workflow::Pom - Tools for maven POM files with git
 
 =head1 VERSION
 
-This documentation refers to App::Git::Workflow::Pom version 0.96001
+This documentation refers to App::Git::Workflow::Pom version 0.96002
 
 =head1 SYNOPSIS
 
