@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION     = 0.96001;
+our $VERSION     = 0.96002;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -60,7 +60,7 @@ sub AUTOLOAD {
 
     my $return = shift @{ $self->{data} };
     if (wantarray) {
-        #cluck "Returning Mock for `$cmd`\n" . Dumper($return), "\t";
+        cluck "Returning Mock for `$cmd`\n" . Dumper($return), "\t" if ref $return ne 'ARRAY';
         return @$return;
     }
     else {
@@ -79,7 +79,7 @@ Mock::App::Git::Workflow::Repository - Mock of a git repository
 
 =head1 VERSION
 
-This documentation refers to Mock::App::Git::Workflow::Repository version 0.96001
+This documentation refers to Mock::App::Git::Workflow::Repository version 0.96002
 
 =head1 SYNOPSIS
 
